EbiFileHandler

Struct EbiFileHandler 

pub struct EbiFileHandler {
    pub name: &'static str,
    pub article: &'static str,
    pub file_extension: &'static str,
    pub is_binary: bool,
    pub format_specification: &'static str,
    pub validator: Option<fn(&mut dyn BufRead) -> Result<()>>,
    pub trait_importers: &'static [EbiTraitImporter],
    pub object_importers: &'static [EbiObjectImporter],
    pub object_importers_fallible: &'static [EbiObjectImporterFallible],
    pub object_exporters: &'static [EbiObjectExporter],
    pub object_exporters_fallible: &'static [EbiObjectExporter],
    pub java_object_handlers: &'static [JavaObjectHandler],
}

Fields

name: &'static strarticle: &'static strfile_extension: &'static stris_binary: boolformat_specification: &'static strvalidator: Option<fn(&mut dyn BufRead) -> Result<()>>trait_importers: &'static [EbiTraitImporter]

This file format can be imported as the given traits. The order matters: importers are attempted in order.

object_importers: &'static [EbiObjectImporter]

This file format can be imported as the given objects. The order matters: importers are attempted in order, fallible importers last. These importers should only fail if the parser failed or the underlying reader fails. If there is a conversion involved that may fail, list it under trait_importers_fallible.

object_importers_fallible: &'static [EbiObjectImporterFallible]

This file format can be imported as the given objects. The order matters: importers are attempted in order, fallible importers last. These importers perform a conversion that may fail.

object_exporters: &'static [EbiObjectExporter]

This file format can be exported to from the given objects. The order matters, because if multiple file handlers can export an object, the one that mentions the object earliest is preferred. Should not fail unless the underlying writer yields an error.

object_exporters_fallible: &'static [EbiObjectExporter]

This file format can be exported to from the given objects. The order matters, because if multiple file handlers can export an object, the one that mentions the object earliest is preferred.

java_object_handlers: &'static [JavaObjectHandler]

Implementations

Source

impl EbiFileHandler

pub fn get_applicable_commands(&self) -> BTreeSet<Vec<&'static EbiCommand>>

pub fn get_producing_commands(&self) -> BTreeSet<Vec<&'static EbiCommand>>

pub fn can_import_as_object(&self, object_type: &EbiObjectType) -> Tri

pub fn can_import_as_trait(&self, trait_type: &EbiTrait) -> bool

pub fn can_export_as_object(&self, object_type: &EbiObjectType) -> Tri