Trait Infinite

pub trait Infinite: Signed {
    // Required method
    fn is_infinite(&self) -> bool;

    // Provided methods
    fn is_finite(&self) -> bool { ... }
    fn is_positive_infinite(&self) -> bool { ... }
    fn is_negative_infinite(&self) -> bool { ... }
}

Required Methods

fn is_infinite(&self) -> bool

Returns true if this value is positive infinity or negative infinity, and false otherwise.

Provided Methods

fn is_finite(&self) -> bool

Returns false if this value is positive infinity or negative infinity, and true otherwise.

fn is_positive_infinite(&self) -> bool

fn is_negative_infinite(&self) -> bool

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Infinite for f64

Source

impl Infinite for i8

Source

impl Infinite for i16

Source

impl Infinite for i32

Source

impl Infinite for i64

Source

impl Infinite for i128

Source

impl Infinite for BigInt

Implementors