pub trait Infinite: Signed {
// Required method
fn is_infinite(&self) -> bool;
// Provided methods
fn is_finite(&self) -> bool { ... }
fn is_positive_infinite(&self) -> bool { ... }
fn is_negative_infinite(&self) -> bool { ... }
}Required Methods
Sourcefn is_infinite(&self) -> bool
fn is_infinite(&self) -> bool
Returns true if this value is positive infinity or negative infinity, and false otherwise.
Provided Methods
Sourcefn is_finite(&self) -> bool
fn is_finite(&self) -> bool
Returns false if this value is positive infinity or negative infinity, and true otherwise.
fn is_positive_infinite(&self) -> bool
fn is_negative_infinite(&self) -> bool
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.